import { fromEvent } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { init, connect, disConnect } from 'echarts';
import { Component, ElementRef, Input, Output, EventEmitter, ViewChild, NgZone, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
class NgxEchartsComponent {
    /**
     * @param {?} el
     * @param {?} ngZone
     */
    constructor(el, ngZone) {
        this.el = el;
        this.ngZone = ngZone;
        this.setOptionConfig = {
            notMerge: true
        };
        this.loadingType = 'default';
        this.autoResize = false;
        this.onInit = new EventEmitter();
        this.onOptionChange = new EventEmitter();
        // events
        this.onClick = new EventEmitter();
        this.onDblClick = new EventEmitter();
        this.onMouseDown = new EventEmitter();
        this.onMouseMove = new EventEmitter();
        this.onMouseUp = new EventEmitter();
        this.onMouseOver = new EventEmitter();
        this.onMouseOut = new EventEmitter();
        this.onGlobalOut = new EventEmitter();
        this.onContextMenu = new EventEmitter();
        // action events
        this.onLegendSelectChanged = new EventEmitter();
        this.onLegendSelected = new EventEmitter();
        this.onLegendUnSelected = new EventEmitter();
        this.onLegendScroll = new EventEmitter();
        this.onDataZoom = new EventEmitter();
        this.onDataRangeSelected = new EventEmitter();
        this.onTimelineChanged = new EventEmitter();
        this.onTimelinePlayChanged = new EventEmitter();
        this.onRestore = new EventEmitter();
        this.onDataViewChanged = new EventEmitter();
        this.onMagicTypeChanged = new EventEmitter();
        this.onGeoSelectChanged = new EventEmitter();
        this.onGeoSelected = new EventEmitter();
        this.onGeoUnSelected = new EventEmitter();
        this.onPieSelectChanged = new EventEmitter();
        this.onPieSelected = new EventEmitter();
        this.onPieUnSelected = new EventEmitter();
        this.onMapSelectChanged = new EventEmitter();
        this.onMapSelected = new EventEmitter();
        this.onMapUnSelected = new EventEmitter();
        this.onAxisAreaSelected = new EventEmitter();
        this.onFocusNodeAdjacency = new EventEmitter();
        this.onUnfocusNodeAdjacency = new EventEmitter();
        this.onBrush = new EventEmitter();
        this.onBrushSelected = new EventEmitter();
        this.onGlobalCursorTaken = new EventEmitter();
        this.onRendered = new EventEmitter();
        this.onFinished = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.resize$ = fromEvent(window, 'resize')
            .pipe(debounceTime(200))
            .subscribe(() => this.resize());
        this.init();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes["theme"] && !changes["theme"].isFirstChange()) {
            this.dispose();
            this.init();
        }
        if (changes["option"] && !changes["option"].isFirstChange()) {
            if (this.echartsInstance) {
                this.setOption();
            }
        }
        if (changes["group"]) {
            this.toggleGroup(changes["group"]);
        }
        if (changes["loading"]) {
            this.toggleLoading();
        }
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        this.resize();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.dispose();
        if (this.resize$) {
            this.resize$.unsubscribe();
        }
    }
    /**
     * @return {?}
     */
    init() {
        if (!this.echartsInstance) {
            this.offsetWidth = this.el.nativeElement.offsetWidth;
            this.offsetHeight = this.el.nativeElement.offsetHeight;
            if (!(this.initOpts && this.initOpts.height) && this.offsetHeight === 0) {
                this.el.nativeElement.style.height = '500px';
            }
            this.ngZone.runOutsideAngular(() => {
                this.echartsInstance = init(this.host.nativeElement, this.theme, this.initOpts);
                this.onInit.emit(this.echartsInstance);
                this.echartsInstance.group = this.group;
                this.buildEvent();
                this.setOption();
            });
        }
        else {
            this.setOption();
        }
    }
    /**
     * @return {?}
     */
    dispose() {
        this.echartsInstance.dispose();
        this.echartsInstance = null;
    }
    /**
     * @return {?}
     */
    setOption() {
        if (this.option) {
            this.echartsInstance.setOption(this.option, this.setOptionConfig);
            this.onOptionChange.emit(this.option);
        }
    }
    /**
     * @param {?} change
     * @return {?}
     */
    toggleGroup(change) {
        if (change.previousValue) {
            disConnect(change.previousValue);
        }
        if (change.currentValue) {
            connect(change.currentValue);
        }
    }
    /**
     * @return {?}
     */
    toggleLoading() {
        if (this.echartsInstance) {
            if (this.loading) {
                this.echartsInstance.showLoading(this.loadingType, this.loadingOpts);
            }
            else {
                this.echartsInstance.hideLoading();
            }
        }
    }
    /**
     * @return {?}
     */
    buildEvent() {
        // events
        this.echartsInstance.on('click', (event) => this.ngZone.run(() => this.onClick.emit(event)));
        this.echartsInstance.on('dblclick', (event) => this.ngZone.run(() => this.onDblClick.emit(event)));
        this.echartsInstance.on('mousedown', (event) => this.ngZone.run(() => this.onMouseDown.emit(event)));
        this.echartsInstance.on('mousemove', (event) => this.ngZone.run(() => this.onMouseMove.emit(event)));
        this.echartsInstance.on('mouseup', (event) => this.ngZone.run(() => this.onMouseUp.emit(event)));
        this.echartsInstance.on('mouseover', (event) => this.ngZone.run(() => this.onMouseOver.emit(event)));
        this.echartsInstance.on('mouseout', (event) => this.ngZone.run(() => this.onMouseOut.emit(event)));
        this.echartsInstance.on('globalout', (event) => this.ngZone.run(() => this.onGlobalOut.emit(event)));
        this.echartsInstance.on('contextmenu', (event) => this.ngZone.run(() => this.onContextMenu.emit(event)));
        // action events
        this.echartsInstance.on('legendselectchanged', (event) => this.ngZone.run(() => this.onLegendSelectChanged.emit(event)));
        this.echartsInstance.on('legendselected', (event) => this.ngZone.run(() => this.onLegendSelected.emit(event)));
        this.echartsInstance.on('legendunselected', (event) => this.ngZone.run(() => this.onLegendUnSelected.emit(event)));
        this.echartsInstance.on('legendscroll', (event) => this.ngZone.run(() => this.onLegendScroll.emit(event)));
        this.echartsInstance.on('datazoom', (event) => this.ngZone.run(() => this.onDataZoom.emit(event)));
        this.echartsInstance.on('datarangeselected', (event) => this.ngZone.run(() => this.onDataRangeSelected.emit(event)));
        this.echartsInstance.on('timelinechanged', (event) => this.ngZone.run(() => this.onTimelineChanged.emit(event)));
        this.echartsInstance.on('timelineplaychanged', (event) => this.ngZone.run(() => this.onTimelinePlayChanged.emit(event)));
        this.echartsInstance.on('restore', (event) => this.ngZone.run(() => this.onRestore.emit(event)));
        this.echartsInstance.on('dataviewchanged', (event) => this.ngZone.run(() => this.onDataViewChanged.emit(event)));
        this.echartsInstance.on('magictypechanged', (event) => this.ngZone.run(() => this.onMagicTypeChanged.emit(event)));
        this.echartsInstance.on('geoselectchanged', (event) => this.ngZone.run(() => this.onGeoSelectChanged.emit(event)));
        this.echartsInstance.on('geoselected', (event) => this.ngZone.run(() => this.onGeoSelected.emit(event)));
        this.echartsInstance.on('geounselected', (event) => this.ngZone.run(() => this.onGeoUnSelected.emit(event)));
        this.echartsInstance.on('pieselectchanged', (event) => this.ngZone.run(() => this.onPieSelectChanged.emit(event)));
        this.echartsInstance.on('pieselected', (event) => this.ngZone.run(() => this.onPieSelected.emit(event)));
        this.echartsInstance.on('pieunselected', (event) => this.ngZone.run(() => this.onPieUnSelected.emit(event)));
        this.echartsInstance.on('mapselectchanged', (event) => this.ngZone.run(() => this.onMapSelectChanged.emit(event)));
        this.echartsInstance.on('mapselected', (event) => this.ngZone.run(() => this.onMapSelected.emit(event)));
        this.echartsInstance.on('mapunselected', (event) => this.ngZone.run(() => this.onMapUnSelected.emit(event)));
        this.echartsInstance.on('axisareaselected', (event) => this.ngZone.run(() => this.onAxisAreaSelected.emit(event)));
        this.echartsInstance.on('focusNodeAdjacency', (event) => this.ngZone.run(() => this.onFocusNodeAdjacency.emit(event)));
        this.echartsInstance.on('unfocusNodeAdjacency', (event) => this.ngZone.run(() => this.onUnfocusNodeAdjacency.emit(event)));
        this.echartsInstance.on('brush', (event) => this.ngZone.run(() => this.onBrush.emit(event)));
        this.echartsInstance.on('brushselected', (event) => this.ngZone.run(() => this.onBrushSelected.emit(event)));
        this.echartsInstance.on('globalcursortaken', (event) => this.ngZone.run(() => this.onGlobalCursorTaken.emit(event)));
        this.echartsInstance.on('rendered', (event) => this.ngZone.run(() => this.onRendered.emit(event)));
        this.echartsInstance.on('finished', (event) => this.ngZone.run(() => this.onFinished.emit(event)));
    }
    /**
     * @return {?}
     */
    resize() {
        if (this.autoResize && this.echartsInstance) {
            /** @type {?} */
            const offsetWidth = this.el.nativeElement.offsetWidth;
            /** @type {?} */
            const offsetHeight = this.el.nativeElement.offsetHeight;
            if (this.offsetWidth !== offsetWidth || this.offsetHeight !== offsetHeight) {
                this.offsetWidth = offsetWidth;
                this.offsetHeight = offsetHeight;
                this.echartsInstance.resize();
            }
        }
    }
}
NgxEchartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-echarts',
                template: "<div #host class=\"echarts-container\"></div>",
                styles: [":host{display:block;height:100%}.echarts-container{height:100%}"]
            }] }
];
/** @nocollapse */
NgxEchartsComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: NgZone }
];
NgxEchartsComponent.propDecorators = {
    theme: [{ type: Input }],
    initOpts: [{ type: Input }],
    option: [{ type: Input }],
    group: [{ type: Input }],
    setOptionConfig: [{ type: Input }],
    loading: [{ type: Input }],
    loadingType: [{ type: Input }],
    loadingOpts: [{ type: Input }],
    autoResize: [{ type: Input }],
    onInit: [{ type: Output }],
    onOptionChange: [{ type: Output }],
    onClick: [{ type: Output }],
    onDblClick: [{ type: Output }],
    onMouseDown: [{ type: Output }],
    onMouseMove: [{ type: Output }],
    onMouseUp: [{ type: Output }],
    onMouseOver: [{ type: Output }],
    onMouseOut: [{ type: Output }],
    onGlobalOut: [{ type: Output }],
    onContextMenu: [{ type: Output }],
    onLegendSelectChanged: [{ type: Output }],
    onLegendSelected: [{ type: Output }],
    onLegendUnSelected: [{ type: Output }],
    onLegendScroll: [{ type: Output }],
    onDataZoom: [{ type: Output }],
    onDataRangeSelected: [{ type: Output }],
    onTimelineChanged: [{ type: Output }],
    onTimelinePlayChanged: [{ type: Output }],
    onRestore: [{ type: Output }],
    onDataViewChanged: [{ type: Output }],
    onMagicTypeChanged: [{ type: Output }],
    onGeoSelectChanged: [{ type: Output }],
    onGeoSelected: [{ type: Output }],
    onGeoUnSelected: [{ type: Output }],
    onPieSelectChanged: [{ type: Output }],
    onPieSelected: [{ type: Output }],
    onPieUnSelected: [{ type: Output }],
    onMapSelectChanged: [{ type: Output }],
    onMapSelected: [{ type: Output }],
    onMapUnSelected: [{ type: Output }],
    onAxisAreaSelected: [{ type: Output }],
    onFocusNodeAdjacency: [{ type: Output }],
    onUnfocusNodeAdjacency: [{ type: Output }],
    onBrush: [{ type: Output }],
    onBrushSelected: [{ type: Output }],
    onGlobalCursorTaken: [{ type: Output }],
    onRendered: [{ type: Output }],
    onFinished: [{ type: Output }],
    host: [{ type: ViewChild, args: ['host',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
class NgxEchartsModule {
}
NgxEchartsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                exports: [
                    NgxEchartsComponent
                ],
                declarations: [
                    NgxEchartsComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */

export { NgxEchartsComponent, NgxEchartsModule };

//# sourceMappingURL=twp0217-ngx-echarts.js.map